==> soliq_id-1.4.37.tar.gz: soliq_test/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:soliq_id/localizations_util.dart';
import 'package:soliq_id/soliq_id.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        colorScheme: ColorScheme.fromSeed(seedColor: Colors.deepPurple),
        useMaterial3: true,
      ),
      home: const MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key, required this.title});

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  openScanner() async {
    await Navigator.push(
      context,
      MaterialPageRoute(
        builder: (context) => SoliqId(
          /// User pinfl
          /// Example: 12345678912345
          pinfl: "12345678912345",

          /// User localization type
          localizationType: LocalizationType.UZ,

          /// User guid
          /// Guid as a token given by the server
          guid:
              "eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJleHAiOjB9.6bWEShkw3Fhdur5TubYJavgPZXWqwNUhXRtL0LJoVCx7o7CZvuWXnnBPKphmjVajuZ0d8TcusOUievxg-lm0lA",

          /// Navigate to Result Screen
          /// If true, the user will be navigated to the result screen after the process is completed
          onNavigate: true,

          /// Event callback function
          /// This function will be called when the process is completed
          /// It will return the result of the process
          /// Example: {"status": "success", "message": "User successfully verified"}
          onEvent: event,
        ),
      ),
    );
  }

  void event(Map<String, dynamic> event) {
    /// Example:
    //   {   "success": success,
    //       "code": code,
    //       "message": message,
    //       "id": id,
    //       "token": token,
    //       "data": {
    //           "pinfl": pinfl,
    //           "surName": sureName,
    //           "name": name,
    //           "patronymicName": fatherName,
    //           "birthDate": birthDate,
    //           "birthPlace": birthPlace,
    //           "docSerial": docSerial,
    //           "docNumber": docNumber,
    //           "livingPlace": livingPlace,
    //           "docGiveDate": docGivenDate,
    //           "docExpirationDate": docExpireDate,
    //           "docGivePlace": docGivenPlace,
    //           "status": status,
    //                          }
    //                                  }

    print(event);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Theme.of(context).colorScheme.inversePrimary,
        title: Text(widget.title),
      ),
      body: Center(
        child: InkWell(
          onTap: openScanner,
          child: const Text('Open Scanner'),
        ),
      ), // This trailing comma makes auto-formatting nicer for build methods.
    );
  }
}

==> soliq_id-1.4.40.tar.gz: soliq_test/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:soliq_id/localizations_util.dart';
import 'package:soliq_id/soliq_id.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        colorScheme: ColorScheme.fromSeed(seedColor: Colors.deepPurple),
        useMaterial3: true,
      ),
      home: const MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key, required this.title});

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  openScanner() async {
    await Navigator.push(
      context,
      MaterialPageRoute(
        builder: (context) => SoliqId(
          /// User pinfl
          /// Example: 12345678912345
          pinfl: "12345678912345",

          /// User localization type
          localizationType: LocalizationType.UZ,

          /// User guid
          /// Guid as a token given by the server
          guid:
              "eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJleHAiOjB9.CIK7UH6euqJj01KjZc7xLbQyt24oZFZ5fIAPV3BfYDDqXT22UuULLym76gPijBjACWwB8Yo2DNNY7113xQcaqA",

          /// Navigate to Result Screen
          /// If true, the user will be navigated to the result screen after the process is completed
          onNavigate: true,

          /// Event callback function
          /// This function will be called when the process is completed
          /// It will return the result of the process
          /// Example: {"status": "success", "message": "User successfully verified"}
          onEvent: event,
        ),
      ),
    );
  }

  void event(Map<String, dynamic> event) {
    /// Example:
    //   {   "success": success,
    //       "code": code,
    //       "message": message,
    //       "id": id,
    //       "token": token,
    //       "data": {
    //           "pinfl": pinfl,
    //           "surName": sureName,
    //           "name": name,
    //           "patronymicName": fatherName,
    //           "birthDate": birthDate,
    //           "birthPlace": birthPlace,
    //           "docSerial": docSerial,
    //           "docNumber": docNumber,
    //           "livingPlace": livingPlace,
    //           "docGiveDate": docGivenDate,
    //           "docExpirationDate": docExpireDate,
    //           "docGivePlace": docGivenPlace,
    //           "status": status,
    //                          }
    //                                  }

    print(event);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Theme.of(context).colorScheme.inversePrimary,
        title: Text(widget.title),
      ),
      body: Center(
        child: InkWell(
          onTap: openScanner,
          child: const Text('Open Scanner'),
        ),
      ), // This trailing comma makes auto-formatting nicer for build methods.
    );
  }
}
